@@ -265,7 +265,8 @@ class Install(install_misc.InstallBase):
         if not use_restricted:
             for pkg in cache.keys():
                 if (cache[pkg].is_installed and
-                        cache[pkg].section.startswith('restricted/')):
+                        cache[pkg].candidate.section.startswith(
+                            'restricted/')):
                     difference.add(pkg)
 
         # Keep packages we explicitly installed.
@@ -276,14 +277,18 @@ class Install(install_misc.InstallBase):
         # at file copy time, we should figure out why grub still fails when
         # apt-install-direct is present during configure_bootloader (code
         # removed).
-        if arch in ('amd64', 'i386'):
+        if arch in ('amd64', 'arm64', 'i386'):
             # We now want grub-pc to be left installed for both EFI and legacy
             # since it makes sure that the right maintainer scripts are run.
             keep.add('grub-pc')
             if subarch == 'efi':
                 keep.add('grub-efi')
                 keep.add('grub-efi-amd64')
+                keep.add('grub-efi-arm64')
                 keep.add('grub-efi-amd64-signed')
+                keep.add('grub-efi-arm64-signed')
+                keep.add('flash-kernel')
+                keep.add('aarch64-laptops-support')
                 keep.add('shim-signed')
                 keep.add('mokutil')
                 try:
@@ -296,13 +301,6 @@ class Install(install_misc.InstallBase):
                 keep.add('linux-signed-generic%s' % altmeta)
             else:
                 keep.add('grub')
-        elif (arch in ('armel', 'armhf') and
-              subarch in ('omap', 'omap4', 'mx5')):
-            keep.add('flash-kernel')
-            keep.add('u-boot-tools')
-        elif arch == 'powerpc':
-            keep.add('yaboot')
-            keep.add('hfsutils')
 
         # Even adding ubiquity as a depends to oem-config-{gtk,kde} doesn't
         # appear to force ubiquity and libdebian-installer4 to copy all of
@@ -438,6 +436,7 @@ class Install(install_misc.InstallBase):
 
                 # Is the path blacklisted?
                 if (not stat.S_ISDIR(st.st_mode) and
+                        '/' in relpath and
                         '/%s' % relpath in self.blacklist):
                     if debug:
                         syslog.syslog('Not copying %s' % relpath)
