@@ -213,6 +213,8 @@ def map_widget_name(prefix, name):
     elif name in string_questions:
         question = string_questions[name]
     else:
+        if name.endswith('1'):
+            name = name[:-1]
         question = '%s/%s' % (prefix, name)
     return question
 
@@ -260,6 +262,7 @@ def ascii_transliterate(exc):
     else:
         return '', exc.start + 1
 
+
 codecs.register_error('ascii_transliterate', ascii_transliterate)
 
 
@@ -272,9 +275,9 @@ def get_languages(current_language_index=-1, only_installable=False):
 
     if only_installable:
         from apt.cache import Cache
-        #workaround for an issue where euid != uid and the
-        #apt cache has not yet been loaded causing a SystemError
-        #when libapt-pkg tries to load the Cache the first time.
+        # workaround for an issue where euid != uid and the
+        # apt cache has not yet been loaded causing a SystemError
+        # when libapt-pkg tries to load the Cache the first time.
         with misc.raised_privileges():
             cache = Cache()
 
@@ -294,12 +297,12 @@ def get_languages(current_language_index=-1, only_installable=False):
         # NO-BREAK SPACE, and we don't care about the NBSP anyway, so strip
         # it.
         #   https://bugs.launchpad.net/bugs/1001542
-        #   (comment #5 and on)
+        #   (comment # 5 and on)
         trans = trans.strip(" \ufeff")
 
         if only_installable:
             pkg_name = 'language-pack-%s' % code
-            #special case these
+            # special case these
             if pkg_name.endswith('_CN'):
                 pkg_name = 'language-pack-zh-hans'
             elif pkg_name.endswith('_TW'):
@@ -333,7 +336,7 @@ def get_languages(current_language_index=-1, only_installable=False):
         # custom sorting).  This at least gives us common sorting rules,
         # like stripping accents.
         collator = icu.Collator.createInstance(icu.Locale('C'))
-    except:
+    except Exception:
         collator = None
 
     def compare_choice(x):
@@ -342,7 +345,7 @@ def get_languages(current_language_index=-1, only_installable=False):
         if collator:
             try:
                 return collator.getCollationKey(x).getByteArray()
-            except:
+            except Exception:
                 pass
         # Else sort by unicode code point, which isn't ideal either,
         # but also has the virtue of sorting like-glyphs together
