@@ -312,6 +312,24 @@ def partition_to_disk(partition):
     return udevadm_disk.get('DEVNAME', partition)
 
 
+@raise_privileges
+def is_bitlocker_partition_encrypted(devpath):
+    """Check if partition is BitLocker encryption."""
+    subp = subprocess.Popen(
+        ['blkid', '--match-tag', 'TYPE', devpath],
+        stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+        universal_newlines=True)
+    result = subp.communicate()[0].split()
+    if result:
+        for line in result:
+            if devpath in line:
+                continue
+            name, value = line.split('=', 1)
+            if 'TYPE' in name and 'BitLocker' in value[1:-1]:
+                return True
+    return False
+
+
 def is_boot_device_removable(boot=None):
     if boot:
         return is_removable(boot)
@@ -447,7 +465,7 @@ def os_prober():
             if res[2] == 'Ubuntu':
                 version = [v for v in re.findall('[0-9.]*', res[1]) if v][0]
                 # Get rid of the superfluous (development version) (11.04)
-                text = re.sub('\s*\(.*\).*', '', res[1])
+                text = re.sub(r'\s*\(.*\).*', '', res[1])
                 _os_prober_oslist[res[0]] = text
                 _os_prober_osvers[res[0]] = version
             else:
@@ -647,7 +665,7 @@ def dmimodel():
             model = proc.communicate()[0]
         if 'apple' in manufacturer:
             # MacBook4,1 - strip the 4,1
-            model = re.sub('[^a-zA-Z\s]', '', model)
+            model = re.sub(r'[^a-zA-Z\s]', '', model)
         # Replace each gap of non-alphanumeric characters with a dash.
         # Ensure the resulting string does not begin or end with a dash.
         model = re.sub('[^a-zA-Z0-9]+', '-', model).rstrip('-').lstrip('-')
@@ -888,4 +906,9 @@ def install_size():
 
 min_install_size = None
 
+
+def launch_uri(uri):
+    subprocess.Popen(['sensible-browser', uri], close_fds=True,
+                     preexec_fn=drop_all_privileges)
+
 # vim:ai:et:sts=4:tw=80:sw=4:
