@@ -117,18 +117,6 @@ class PageBase(plugin.PluginUI):
         """Returns true if the user should be automatically logged in."""
         raise NotImplementedError('get_auto_login')
 
-    def set_encrypt_home(self, value):
-        """Set whether the home directory should be encrypted."""
-        raise NotImplementedError('set_encrypt_home')
-
-    def set_force_encrypt_home(self, value):
-        """Forces whether the home directory should be encrypted."""
-        raise NotImplementedError('set_force_encrypt_home')
-
-    def get_encrypt_home(self):
-        """Returns true if the home directory should be encrypted."""
-        raise NotImplementedError('get_encrypt_home')
-
     def username_error(self, msg):
         """The selected username was bad."""
         raise NotImplementedError('username_error')
@@ -260,16 +248,6 @@ class PageGtk(PageBase):
     def get_auto_login(self):
         return self.login_auto.get_active()
 
-    def set_encrypt_home(self, value):
-        print('Ecryptfs is deprecated')
-
-    def set_force_encrypt_home(self, value):
-        print('Ecryptfs is deprecated')
-
-    # Ecryptfs is deprecated
-    def get_encrypt_home(self):
-        return False
-
     def username_error(self, msg):
         self.username_ok.hide()
         m = '<small><span foreground="darkred"><b>%s</b></span></small>' % msg
@@ -479,8 +457,6 @@ class PageKde(PageBase):
         # self.page.password.textChanged[str].connect(self.on_password_changed)
         # self.page.verified_password.textChanged[str].connect(
         #    self.on_verified_password_changed)
-        self.page.login_pass.clicked[bool].connect(self.on_login_pass_clicked)
-        self.page.login_auto.clicked[bool].connect(self.on_login_auto_clicked)
 
         self.page.password_debug_warning_label.setVisible(
             'UBIQUITY_DEBUG' in os.environ)
@@ -539,22 +515,6 @@ class PageKde(PageBase):
     def get_auto_login(self):
         return self.page.login_auto.isChecked()
 
-    def on_login_pass_clicked(self, checked):
-        print("Ecryptfs is deprecated")
-
-    def on_login_auto_clicked(self, checked):
-        print("Ecryptfs is deprecated")
-
-    def set_encrypt_home(self, value):
-        print("Ecryptfs is deprecated")
-
-    def set_force_encrypt_home(self, value):
-        print("Ecryptfs is deprecated")
-
-    # Ecryptfs is deprecated
-    def get_encrypt_home(self):
-        return False
-
     def username_error(self, msg):
         self.page.username_error_reason.setText(msg)
         self.page.username_error_image.show()
@@ -640,16 +600,6 @@ class PageNoninteractive(PageBase):
     def get_auto_login(self):
         return self.auto_login
 
-    def set_encrypt_home(self, value):
-        print('Ecryptfs is deprecated')
-
-    def set_force_encrypt_home(self, value):
-        print('Ecryptfs is deprecated')
-
-    # Ecrypts is deprecated
-    def get_encrypt_home(self):
-        return False
-
     def username_error(self, msg):
         """The selected username was bad."""
         print('\nusername error: %s' % msg, file=self.console)
@@ -713,14 +663,6 @@ class Page(plugin.Plugin):
                 self.ui.set_auto_login(auto_login == 'true')
             except debconf.DebconfError:
                 pass
-            try:
-                encrypt_home = self.db.get('user-setup/force-encrypt-home')
-                if not encrypt_home:
-                    encrypt_home = self.db.get('user-setup/encrypt-home')
-                self.ui.set_encrypt_home(encrypt_home == 'true')
-                self.ui.set_force_encrypt_home(encrypt_home == 'true')
-            except debconf.DebconfError:
-                pass
         try:
             empty = self.db.get('user-setup/allow-password-empty') == 'true'
         except debconf.DebconfError:
@@ -770,7 +712,6 @@ class Page(plugin.Plugin):
         password = self.ui.get_password()
         password_confirm = self.ui.get_verified_password()
         auto_login = self.ui.get_auto_login()
-        encrypt_home = self.ui.get_encrypt_home()
 
         self.preseed('passwd/user-fullname', fullname)
         self.preseed('passwd/username', username)
@@ -782,7 +723,7 @@ class Page(plugin.Plugin):
         else:
             self.preseed('passwd/user-uid', '')
         self.preseed_bool('passwd/auto-login', auto_login)
-        self.preseed_bool('user-setup/encrypt-home', encrypt_home)
+        self.preseed_bool('user-setup/encrypt-home', False)
 
         hostname = self.ui.get_hostname()
 
